@@ -5,7 +5,7 @@
 """
 
 import click
-from jaws_libp.clients import CategoryConsumer
+from jaws_libp.console import CategoryConsoleConsumer
 
 
 # pylint: disable=missing-function-docstring,no-value-for-parameter
@@ -14,7 +14,7 @@ from jaws_libp.clients import CategoryConsumer
 @click.option('--nometa', is_flag=True, help="Exclude audit headers and timestamp")
 @click.option('--export', is_flag=True, help="Dump records in AVRO JSON format")
 def list_categories(monitor, nometa, export) -> None:
-    consumer = CategoryConsumer('list_categories.py')
+    consumer = CategoryConsoleConsumer('list_categories.py')
 
     consumer.consume_then_done(monitor, nometa, export)
 
